Objects Description — django-admin-charts 0.25.0 documentation

# Objects Description

## `DashboardStatsCriteria`

To configure criteria for dashboard graphs

> Attributes:

> > - `criteria_name` - Unique word .

> > - `criteria_fix_mapping` - JSON data key-value pairs.

> > - `dynamic_criteria_field_name` - Dynamic criteria field.

> > - `criteria_dynamic_mapping` - JSON data key-value pairs.

> > - `created_date` - record created date.

> > - `updated_date` - record updated date.

> Name of DB table: dash_stats_criteria

## `DashboardStats`

To configure graphs for dashboard

> Attributes:

> > - `graph_key` - unique graph name.

> > - `graph_title` - graph title.

> > - `model_app_name` - App name of model.

> > - `model_name` - model name.

> > - `date_field_name` - Date field of model_name.

> > - `criteria` - many-to-many relationship.

> > - `is_visible` - enable/disable.

> > - `created_date` - record created date.

> > - `updated_date` - record updated date.

> Name of DB table: dashboard_stats